@@ -14,7 +14,7 @@ use strict;
 use IO::File;
 use Carp;
 
-our $VERSION = 1.0_1; # woo hoo!
+our $VERSION = 1.0_2;
 use Geo::ReadGRIB::PlaceIterator;
 
 my $LIB_DIR = "./";
@@ -597,9 +597,9 @@ sub lalo2offset {
         $out =  ( ( $self->La1 - $lat ) / $self->LaInc ) * $self->Ni 
                 + ( ($long - $self->Lo1 ) / $self->LoInc );
     }
-
-    return int( $out );
-#    return sprintf "%d", $out;
+ 
+#    return int( $out );
+    return sprintf "%d", $out;
 }
 
 #--------------------------------------------------------------------------
